@@ -1,6 +1,6 @@
 package Parse::CPAN::Packages::Distribution;
 use strict;
-use base qw( Class::Accessor::Chained );
+use base qw( Class::Accessor::Fast );
 __PACKAGE__->mk_accessors(qw( prefix dist version maturity filename
                               cpanid distvname packages ));
 use vars qw($VERSION);
@@ -9,7 +9,8 @@ $VERSION = '2.12';
 sub new {
     my $class = shift;
     my $self = $class->SUPER::new;
-    $self->packages( [] );
+    $self->packages([]);
+    return $self;
 }
 
 sub contains {
@@ -17,4 +18,9 @@ sub contains {
     return @{ $self->packages };
 }
 
+sub add_package {
+    my $self = shift;
+    push @{ $self->packages }, @_;
+}
+
 1;
